@@ -69,20 +69,19 @@ class display_volume_detail(DetailView):
                     for stat_type in models.stat_type.objects.all():
                         stat_type_name = stat_type.name
                         client_lun_cvlabel_entry = client_lun_cvlabel_entries[0]
-                        client_stat_entries = models.stat_entry.objects.filter(
+                        client_stat_entry = models.stat_entry.objects.filter(
                             host=client,
                             disk=client_lun_cvlabel_entry.disk,
                             type=stat_type,
                         ).latest()
 
-                        for client_stat_entry in client_stat_entries:
-                            #   Find the latest entry of particular type
-                            LOGGER.info('Adding stat entry: %s', client_stat_entry.type.name)
-                            stat_value = client_stat_entry.value
-                            if stat_type in client_data:
-                                client_data[stat_type_name] += stat_value
-                            else:
-                                client_data[stat_type_name] = stat_value
+                        #   Find the latest entry of particular type
+                        LOGGER.info('Adding stat entry: %s', client_stat_entry.type.name)
+                        stat_value = client_stat_entry.value
+                        if stat_type in client_data:
+                            client_data[stat_type_name] += stat_value
+                        else:
+                            client_data[stat_type_name] = stat_value
 
             all_clients_data.append(client_data)
 
